import smtplib
import ssl
from os.path import basename
from email.mime.text import MIMEText
from email.mime.application import MIMEApplication
import mimetypes
from email.mime.multipart import MIMEMultipart
from email import encoders
from email.message import Message
from email.mime.audio import MIMEAudio
from email.mime.base import MIMEBase
from email.mime.image import MIMEImage


def dictfetchall(cursor):
    "Return all rows from a cursor as a Python dictionary"
    columns = [col[0] for col in cursor.description]
    return [
        dict(zip(columns, row))
        for row in cursor.fetchall()
    ]

def build_email_message(message_object):
    """Creates message structure to pass to email

    Keyword arguments:
    message_object -- Dictionary that holds message information
    message = {
        'subject' : 'string',
        'from' : 'string',
        'to' : 'string',
        'text': 'string',
        'file': (csv file_type)
        }
    """
    message = MIMEMultipart()

    message["subject"] = message_object["subject"]
    message["from"] = message_object["from"]
    message["to"] = message_object["to"]

    text = message_object["text"]

    if text:
        message.attach(MIMEText(text))
    try:
        file = message_object['file']
        with open(file, "rb") as file_attachment:
            part = MIMEApplication(file_attachment.read(), Name=basename(file))
        part['Content-Disposition'] = f'attachment; filenames={basename(file)}'
        message.attach(part)
    except:
        print('No file found')

    return message


def send_email(smtp_config, message):
    """ Sends email to destination based off smtp_config

    Keyword arguments:
    smtp_config -- Dictionary that holds smpt account information
        smtp_config = {
            'username' : 'string',
            'password' : 'string',
            'server' : 'string',
            'port': int,
            }
    
    message - object returned from build_email_message
    """
    context = ssl.create_default_context()

    with smtplib.SMTP(smtp_config['server'], smtp_config['port']) as server:
            server.starttls(context=context)
            server.login(user=smtp_config['username'], password=smtp_config['password'])
            server.sendmail(from_addr=message['from'], to_addrs=message['to'], msg=message.as_string())



import requests
import base64

class PaligoClient():
    def __init__(self, user="", key=""):
        paligo_string = f"{user}:{key}".encode("utf-8")
        auth = base64.b64encode(paligo_string)
        self.headers = {
            'Accept': 'application/json',
            'Authorization': f'''Basic {auth}''',
        }

    def get_documents(self, parent):
        '''Get all documents in a parent folder, takes the folder UUID'''
        document = requests.get(f'''https://mesangs.paligoapp.com/api/v2/documents?parent={parent}''', headers=self.headers)
        return document.json()["documents"]

    def get_document(self, doc_id):
        '''Get all document content, takes the document ID or UUID'''
        document = requests.get(f'''https://mesangs.paligoapp.com/api/v2/documents/{doc_id}''', headers=self.headers)
        return document.json()

    def get_folders(self, parent=""):
        '''Get all folders in a parent folder, takes the folder UUID'''
        folders = requests.get(f'''https://mesangs.paligoapp.com/api/v2/folders?parent={parent}''', headers=self.headers)
        return folders.json()["folders"]

    def get_folder(self, folder_id):
        '''Get folder, takes the folder ID or UUID'''
        folder = requests.get(f'''https://mesangs.paligoapp.com/api/v2/folders/{folder_id}''', headers=self.headers)
        return folder.json()["children"]

    def get_images(self, parent):
        '''Get all images in a parent folder, takes the folder UUID'''
        images = requests.get(f'''https://mesangs.paligoapp.com/api/v2/images?parent={parent}''', headers=self.headers)
        return images.json()["images"]

    def get_image(self, image_id):
        '''Gets information about an image, takes the image ID or UUID'''
        image = requests.get(f'''https://mesangs.paligoapp.com/api/v2/images/{image_id}''', headers=self.headers)
        return image.json()

    def download_image(self, image_id, path):
        '''Download an image from paligo. Takes the image ID or UUID and the filename and path to save the file at.'''
        with requests.get(f'''https://mesangs.paligoapp.com/api/v2/images/{image_id}?size=&download=true''', headers=self.headers) as r:
            with open(path, 'wb') as f:
                f.write(r.content)



from distutils.core import setup
import setuptools

setup(
    name='mesa-solutions-utils',
    packages=['MesaSoapManager', 'ODCHelperFunctions', 'PaligoClient'],
    version='1.1.1',
    license='MIT',
    description='Various utilities functions and classes',
    author='Mesa Natural Gas Solutions, LLC',
    author_email='support@mesangs.com',
    url='https://dev.azure.com/mesa-ngs/_git/mesa-solutions-utils',
    download_url='https://dev.azure.com/mesa-ngs/_git/mesa-solutions-utils',
    keywords=['Microsoft Dynamics NAV', 'Paligo' 'SOAP'],
    install_requires=[
        'zeep>=3,<4',
        'requests>=2,<3',
    ]
)
